import { BlurPass, KernelSize } from 'postprocessing';
export interface BloomProps {
    /**
     * The intensity of the bloom effect.
     *
     * @default 1
     * @type {number}
     * @memberof BloomProps
     */
    intensity?: number;
    /**
     *  An efficient, incremental blur pass.
     *
     * @type {BlurPass}
     * @memberof BloomProps
     */
    blurPass?: BlurPass;
    /**
     * The width of the render
     *
     * @type {number}
     * @memberof BloomProps
     */
    width?: number;
    /**
     * The height of the render
     *
     * @type {number}
     * @memberof BloomProps
     */
    height?: number;
    /**
     * The kernel size.
     *
     * @default KernelSize.LARGE
     *
     * @type {KernelSize}
     * @memberof BloomProps
     */
    kernelSize?: KernelSize;
    /**
     * The luminance threshold. Raise this value to mask out darker elements in the scene. Range is [0, 1].
     *
     * @default 0.9
     *
     * @type {number}
     * @memberof BloomProps
     */
    luminanceThreshold?: number;
    /**
     * Controls the smoothness of the luminance threshold. Range is [0, 1].
     *
     * @default 0.025
     *
     * @type {number}
     * @memberof BloomProps
     */
    luminanceSmoothing?: number;
    /**
     * Enables mip map blur.
     *
     * @default false
     *
     * @type {boolean}
     * @memberof BloomProps
     */
    mipMapBlur?: boolean;
}
export declare const Bloom: import("vue").DefineComponent<BloomProps, {}, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<BloomProps>, {}>;
